<?php

namespace Focus\Chairman\Policies;

use Litepie\User\Contracts\UserPolicy;
use Focus\Chairman\Models\Chairman;

class ChairmanPolicy
{

    /**
     * Determine if the given user can view the chairman.
     *
     * @param UserPolicy $user
     * @param Chairman $chairman
     *
     * @return bool
     */
    public function view(UserPolicy $user, Chairman $chairman)
    {
        if ($user->canDo('chairman.chairman.view') && $user->isAdmin()) {
            return true;
        }

        return $chairman->user_id == user_id() && $chairman->user_type == user_type();
    }

    /**
     * Determine if the given user can create a chairman.
     *
     * @param UserPolicy $user
     * @param Chairman $chairman
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('chairman.chairman.create');
    }

    /**
     * Determine if the given user can update the given chairman.
     *
     * @param UserPolicy $user
     * @param Chairman $chairman
     *
     * @return bool
     */
    public function update(UserPolicy $user, Chairman $chairman)
    {
        if ($user->canDo('chairman.chairman.edit') && $user->isAdmin()) {
            return true;
        }

        return $chairman->user_id == user_id() && $chairman->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given chairman.
     *
     * @param UserPolicy $user
     * @param Chairman $chairman
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Chairman $chairman)
    {
        return $chairman->user_id == user_id() && $chairman->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given chairman.
     *
     * @param UserPolicy $user
     * @param Chairman $chairman
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Chairman $chairman)
    {
        if ($user->canDo('chairman.chairman.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given chairman.
     *
     * @param UserPolicy $user
     * @param Chairman $chairman
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Chairman $chairman)
    {
        if ($user->canDo('chairman.chairman.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
