<?php

namespace Focus\Chairman\Providers;

use Illuminate\Support\ServiceProvider;

class ChairmanServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'chairman');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'chairman');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('focus.chairman', function ($app) {
            return $this->app->make('Focus\Chairman\Chairman');
        });

                // Bind Chairman to repository
        $this->app->bind(
            'Focus\Chairman\Interfaces\ChairmanRepositoryInterface',
            \Focus\Chairman\Repositories\Eloquent\ChairmanRepository::class
        );

        $this->app->register(\Focus\Chairman\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Focus\Chairman\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['focus.chairman'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('focus/chairman.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/chairman')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/chairman')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
